###############################################################################
#
#   CORA v3.6 - revised parameters (June 2012)
#
###############################################################################
#
###############################################################################
#
#   Global Parameters
#
###############################################################################
BEGIN GLOBAL_PARAMETERS
  DES_MOD             Test and CAE                     ; Header of the evaluation
  DES_GLO             CORA sample data set loadcase 01 ; Sub-header of the evaluation
#
# Global settings to define the interval of evaluation
  A_THRES             0.030                 ; Threshold to set the start of the interval of evaluation [0,...,1]
  B_THRES             0.075                 ; Threshold to set the end of the interval of evaluation [0,...,1]
  A_EVAL              0.010                 ; Extension of the interval of evaluation [0,...,1]
  B_DELTA_END         0.200                 ; Additional parameter to shorten the interval of evaluation (width of the corridor: A_DELTA_END*Y_NORM) 0 = disabled
  T_MIN/T_MAX         automatic automatic   ; Manually defined start (time) and end (time) of the interval of evaluation (automatic = calculated for each channel)
  T_UNIT              s                     ; Unit of T_MIN, T_MAX, t_min and t_max
#
# Global settings of the corridor method
  K                   2                     ; Transition between ratings of 1 and 0 of the corridor method [-] (1 = linear, 2 = quadratic ...)
  G_1                 0.50                  ; Weighting factor of the corridor method [-]
  a_0/b_0             0.05     0.50         ; Width of the inner and outer corridor [-]
  a_sigma/b_sigma     0        0            ; Multiples of the standard deviation to widen the inner and outer corridor [-]
# Global settings of the cross correlation method
  D_MIN               0.01                  ; delta_min as share of the interval of evaluation [0,...,1]
  D_MAX               0.12                  ; delta_max as share of the interval of evaluation [0,...,1]
  INT_MIN             0.80                  ; Minimum overlap of the interval [0,...,1]
  K_V                 10                    ; Transition between ratings of 1 and 0 of the progression rating [-] (1 = linear, 2 = quadratic ...)
  K_G                 1                     ; Transition between ratings of 1 and 0 of the size rating [-] (1 = linear, 2 = quadratic ...)
  K_P                 1                     ; Transition between ratings of 1 and 0 of the phase shift rating [-] (1 = linear, 2 = quadratic ...)
  G_V                 0.50                  ; Weighting factors of the progression rating [-]
  G_G                 0.25                  ; Weighting factors of the size rating [-]
  G_P                 0.25                  ; Weighting factors of the phase shift rating [-]
  G_2                 0.50                  ; Weighting factors of the cross correlation method [-]
# Normalisation of the the weighting factors
  WF_NORM             YES                   ; Normalisation of the weighting factors [YES/NO]?
# Signal settings
  ISONAME_1-2/11-12   YES YES               ; Consideration of the position 1/2 (test object, seating position) and 11/12 (fine location 3 - dummy) of the ISO code [YES/NO]
  MIN_NORM            0.00                  ; Threshold (as fraction of the global absolute maximum amplitude) to start special treatment of secondary axis [0,...,1]
  Y_NORM              extremum              ; Type of calculation of Y_NORM (extremum or value)
#
# Format settings of the html report
  OUTPUT_FORMAT       Hypergraph            ; Export format (LSPOST, PAMVIEW or Hypergraph)
# Layout of the html report
  FONT_SMALL          12                    ; Size of the small font
  FONT_LARGE          14                    ; Size of the large font
  PreT_LC/PostT_LC    -1  -1                ; Expansion of the plotted interval of the curves (-1: complete curve)
END GLOBAL_PARAMETERS
#
###############################################################################
#
#  Loadcase
#  x = use global settings
#
###############################################################################
BEGIN LOADCASE
  NAM_LC              Evaluation of CAE_01/02          ; Header of the loadcase
  DES_LC              Loadcase 01                      ; Sub-header of the loadcase
  WF_LC               1                                ; Weighting factor of the loadcase
#
# Layout of the html report
  PreT_LC             x                                ; Expansion of the plotted interval of the curves (pre)
  PostT_LC            x                                ; Expansion of the plotted interval of the curves (post)
#
  BEGIN SUBLOADCASE
    NAM_SLC             CAE 1                          ; Header of the sub-loadcase (experiment)
    DES_SLC             Using ISO format 1.0           ; Sub-header of the sub-loadcase
    WF_SLC              1                              ; Weighting factor of the sub-loadcase
    METHOD              cora                           ; Type of evaluation [cora/ISO9790]
#
    BEGIN DATAFILES
#     Name                                     unit    g   timeshift
#     Reference
      ../../data/loadcase_01/iso/test_01.iso   m-Kg-s  NO  0.0
      ../../data/loadcase_01/iso/test_02.iso   m-Kg-s  NO  0.0
      ../../data/loadcase_01/iso/test_03.iso   m-Kg-s  NO  0.0
      ../../data/loadcase_01/iso/test_04.iso   m-Kg-s  NO  0.0
#     Simulation
      ../../data/loadcase_01/iso/cae_01.iso    m-Kg-s  NO  0.0
    END DATAFILES
    BEGIN SIGNALS
#     Channels
#     Name              WF  Y_norm     t_min     t_max     g_V  g_G  g_P  g1  g2  a_0  b_0   a_t       a_sigma  b_sigma  D_min  D_max  Filter
      S1SENS010000DS0D  1   x          x         x         x    x    x    x   x   x    x     NOTSPEC   x        x        x      x      0
      S1SENS020000FO0D  1   x          x         x         x    x    x    x   x   x    x     NOTSPEC   x        x        x      x      0
      S1SENS030000ACXA  1   x          x         x         x    x    x    x   x   x    x     NOTSPEC   x        x        x      x      0
      S1SENS030000ACYA  1   x          x         x         x    x    x    x   x   x    x     NOTSPEC   x        x        x      x      0
      S1SENS030000ACZA  1   x          x         x         x    x    x    x   x   x    x     NOTSPEC   x        x        x      x      0
      S1SENS040000FOXA  1   x          x         x         x    x    x    x   x   x    x     NOTSPEC   x        x        x      x      0
      S1SENS040000FOYA  1   x          x         x         x    x    x    x   x   x    x     NOTSPEC   x        x        x      x      0
      S1SENS040000FOZA  1   x          x         x         x    x    x    x   x   x    x     NOTSPEC   x        x        x      x      0
      S1SENS040000MOXB  1   x          x         x         x    x    x    x   x   x    x     NOTSPEC   x        x        x      x      0
      S1SENS040000MOYB  1   x          x         x         x    x    x    x   x   x    x     NOTSPEC   x        x        x      x      0
      S1SENS040000MOZB  1   x          x         x         x    x    x    x   x   x    x     NOTSPEC   x        x        x      x      0
      S1SENS050000DSXC  1   x          x         x         x    x    x    x   x   x    x     NOTSPEC   x        x        x      x      0
    END SIGNALS
  END SUBLOADCASE
#
#
  BEGIN SUBLOADCASE
    NAM_SLC             CAE 2                          ; Header of the sub-loadcase (experiment)
    DES_SLC             Using XYData format            ; Sub-header of the sub-loadcase
    WF_SLC              1                              ; Weighting factor of the sub-loadcase
    METHOD              cora                           ; Type of evaluation [cora/ISO9790]
#
    BEGIN DATAFILES
#     Name                                        unit    g   timeshift
#     Reference
      ../../data/loadcase_01/xydata/test_01.dat   m-Kg-s  NO  0.0
      ../../data/loadcase_01/xydata/test_02.dat   m-Kg-s  NO  0.0
      ../../data/loadcase_01/xydata/test_03.dat   m-Kg-s  NO  0.0
      ../../data/loadcase_01/xydata/test_04.dat   m-Kg-s  NO  0.0
#     Simulation
      ../../data/loadcase_01/xydata/cae_02.dat    m-Kg-s  NO  0.0
    END DATAFILES
    BEGIN SIGNALS
#     Channels
#     Name              WF  Y_norm     t_min     t_max     g_V  g_G  g_P  g1  g2  a_0  b_0   a_t       a_sigma  b_sigma  D_min  D_max  Filter
      S1SENS010000DS0D  1   x          x         x         x    x    x    x   x   x    x     NOTSPEC   x        x        x      x      0
      S1SENS020000FO0D  1   x          x         x         x    x    x    x   x   x    x     NOTSPEC   x        x        x      x      0
      S1SENS030000ACXA  1   x          x         x         x    x    x    x   x   x    x     NOTSPEC   x        x        x      x      0
      S1SENS030000ACYA  1   x          x         x         x    x    x    x   x   x    x     NOTSPEC   x        x        x      x      0
      S1SENS030000ACZA  1   x          x         x         x    x    x    x   x   x    x     NOTSPEC   x        x        x      x      0
      S1SENS040000FOXA  1   x          x         x         x    x    x    x   x   x    x     NOTSPEC   x        x        x      x      0
      S1SENS040000FOYA  1   x          x         x         x    x    x    x   x   x    x     NOTSPEC   x        x        x      x      0
      S1SENS040000FOZA  1   x          x         x         x    x    x    x   x   x    x     NOTSPEC   x        x        x      x      0
      S1SENS040000MOXB  1   x          x         x         x    x    x    x   x   x    x     NOTSPEC   x        x        x      x      0
      S1SENS040000MOYB  1   x          x         x         x    x    x    x   x   x    x     NOTSPEC   x        x        x      x      0
      S1SENS040000MOZB  1   x          x         x         x    x    x    x   x   x    x     NOTSPEC   x        x        x      x      0
      S1SENS050000DSXC  1   x          x         x         x    x    x    x   x   x    x     NOTSPEC   x        x        x      x      0
    END SIGNALS
  END SUBLOADCASE
#
END LOADCASE
#
